@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2019 The PHP Group                                |
+  | Copyright (c) 2006-2020 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -120,8 +120,17 @@ const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg{
 		"No valid cipher found in the ssl ciphers list."},
 	{ xdevapi_exception::Code::no_valid_ciphersuite_in_list,
 		"No valid cipher suite found in the tls ciphersuites list."},
+	{ xdevapi_exception::Code::port_nbr_not_allowed_with_srv_uri,
+		"Specifying a port number with DNS SRV lookup is not allowed"},
+	{ xdevapi_exception::Code::provided_invalid_uri,
+		"Incorrect URI string provided"},
+	{ xdevapi_exception::Code::unix_socket_not_allowed_with_srv,
+		"Using Unix domain sockets with DNS SRV lookup is not allowed"},
+	{ xdevapi_exception::Code::url_list_not_allowed,
+		"URI with a list of URL not allowed."},
 };
 
+/* {{{ to_sql_state */
 string to_sql_state(const string& sql_state)
 {
 	return sql_state.empty() ? General_sql_state : sql_state;
